pub struct Id<T>(/* private fields */);Expand description
A string identifier for a resource in the registry.
The type parameter T indicates type of the underlying resource.
Specifications
An Id consists of two parts: a module part for namespacing uses and a name part for identification.
Each part is an ASCII string made up with uppercase or lowercase letters, digits, hyphen, period and underscore,
with a maximum length of 12. i.e. ^[a-zA-Z0-9._-]{1,12}$.
The bahaviour is undefined unless conditions above are satisfied.
String Representation
String representation for a certain Id would be the module part and name part concatenated by a slash (/).
e.g. module/name.
Comparison
Id is guaranteed to have the same comparison behaviour as its corresponding string representation.
Implementations
Sourceimpl<T> Id<T>
impl<T> Id<T>
Sourcepub const fn new(module: ArrayString<12>, name: ArrayString<12>) -> Id<T>
pub const fn new(module: ArrayString<12>, name: ArrayString<12>) -> Id<T>
Create an Id with specified module and name part.